# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/assignment_service_v2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import assignment_item_v2_pb2 as eolymp_dot_course_dot_assignment__item__v2__pb2
from eolymp.course import assignment_v2_pb2 as eolymp_dot_course_dot_assignment__v2__pb2
from eolymp.course import module_item_pb2 as eolymp_dot_course_dot_module__item__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)eolymp/course/assignment_service_v2.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a&eolymp/course/assignment_item_v2.proto\x1a!eolymp/course/assignment_v2.proto\x1a\x1f\x65olymp/course/module_item.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa4\x01\n\x17\x43reateAssignmentV2Input\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12/\n\x0bstart_after\x18\x1e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x63omplete_before\x18\x1f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x64uration\x18# \x01(\r\"\x1a\n\x18\x43reateAssignmentV2Output\",\n\x17\x44\x65leteAssignmentV2Input\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteAssignmentV2Output\"+\n\x16StartAssignmentV2Input\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"\x19\n\x17StartAssignmentV2Output\"\x18\n\x16ListAssignmentsV2Input\"E\n\x17ListAssignmentsV2Output\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.eolymp.course.AssignmentV2\"/\n\x1aListAssignmentItemsV2Input\x12\x11\n\tmodule_id\x18\x01 \x01(\t\"M\n\x1bListAssignmentItemsV2Output\x12.\n\x05items\x18\x01 \x03(\x0b\x32\x1f.eolymp.course.AssignmentItemV2\"t\n\x1d\x44\x65scribeAssignmentItemV2Input\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12\x0f\n\x07item_id\x18\x02 \x01(\t\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.course.ModuleItem.Extra\"O\n\x1e\x44\x65scribeAssignmentItemV2Output\x12-\n\x04item\x18\x01 \x01(\x0b\x32\x1f.eolymp.course.AssignmentItemV2\"\xfe\x01\n\x1bUpdateAssignmentItemV2Input\x12?\n\x05patch\x18\x01 \x03(\x0e\x32\x30.eolymp.course.UpdateAssignmentItemV2Input.Patch\x12\x11\n\tmodule_id\x18\x02 \x01(\t\x12\x0f\n\x07item_id\x18\x03 \x01(\t\x12-\n\x04item\x18\x04 \x01(\x0b\x32\x1f.eolymp.course.AssignmentItemV2\"K\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07\x45XCUSED\x10\x01\x12\x12\n\x0eGRADE_OVERRIDE\x10\x02\x12\x18\n\x14GRADE_OVERRIDE_RESET\x10\x03\"\x1e\n\x1cUpdateAssignmentItemV2Output\"@\n\x1aResetAssignmentItemV2Input\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12\x0f\n\x07item_id\x18\x02 \x01(\t\"\x1d\n\x1bResetAssignmentItemV2Output2\xf5\x0b\n\x13\x41ssignmentServiceV2\x12\xa3\x01\n\x10\x43reateAssignment\x12&.eolymp.course.CreateAssignmentV2Input\x1a\'.eolymp.course.CreateAssignmentV2Output\">\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0e\"\x0c/assignments\x12\xaf\x01\n\x10\x44\x65leteAssignment\x12&.eolymp.course.DeleteAssignmentV2Input\x1a\'.eolymp.course.DeleteAssignmentV2Output\"J\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1a*\x18/assignments/{module_id}\x12\xb1\x01\n\x0fStartAssignment\x12%.eolymp.course.StartAssignmentV2Input\x1a&.eolymp.course.StartAssignmentV2Output\"O\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02 *\x1e/assignments/{module_id}/start\x12\x9f\x01\n\x0fListAssignments\x12%.eolymp.course.ListAssignmentsV2Input\x1a&.eolymp.course.ListAssignmentsV2Output\"=\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/assignments\x12\xbd\x01\n\x13ListAssignmentItems\x12).eolymp.course.ListAssignmentItemsV2Input\x1a*.eolymp.course.ListAssignmentItemsV2Output\"O\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02 \x12\x1e/assignments/{module_id}/items\x12\xd0\x01\n\x16\x44\x65scribeAssignmentItem\x12,.eolymp.course.DescribeAssignmentItemV2Input\x1a-.eolymp.course.DescribeAssignmentItemV2Output\"Y\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02*\x12(/assignments/{module_id}/items/{item_id}\x12\xcb\x01\n\x14UpdateAssignmentItem\x12*.eolymp.course.UpdateAssignmentItemV2Input\x1a+.eolymp.course.UpdateAssignmentItemV2Output\"Z\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02*\"(/assignments/{module_id}/items/{item_id}\x12\xce\x01\n\x13ResetAssignmentItem\x12).eolymp.course.ResetAssignmentItemV2Input\x1a*.eolymp.course.ResetAssignmentItemV2Output\"`\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x30\"./assignments/{module_id}/items/{item_id}/resetB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.assignment_service_v2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _ASSIGNMENTSERVICEV2.methods_by_name['CreateAssignment']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['CreateAssignment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\016\"\014/assignments'
  _ASSIGNMENTSERVICEV2.methods_by_name['DeleteAssignment']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['DeleteAssignment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\032*\030/assignments/{module_id}'
  _ASSIGNMENTSERVICEV2.methods_by_name['StartAssignment']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['StartAssignment']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002 *\036/assignments/{module_id}/start'
  _ASSIGNMENTSERVICEV2.methods_by_name['ListAssignments']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['ListAssignments']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\016\022\014/assignments'
  _ASSIGNMENTSERVICEV2.methods_by_name['ListAssignmentItems']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['ListAssignmentItems']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002 \022\036/assignments/{module_id}/items'
  _ASSIGNMENTSERVICEV2.methods_by_name['DescribeAssignmentItem']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['DescribeAssignmentItem']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002*\022(/assignments/{module_id}/items/{item_id}'
  _ASSIGNMENTSERVICEV2.methods_by_name['UpdateAssignmentItem']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['UpdateAssignmentItem']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002*\"(/assignments/{module_id}/items/{item_id}'
  _ASSIGNMENTSERVICEV2.methods_by_name['ResetAssignmentItem']._options = None
  _ASSIGNMENTSERVICEV2.methods_by_name['ResetAssignmentItem']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0020\"./assignments/{module_id}/items/{item_id}/reset'
  _CREATEASSIGNMENTV2INPUT._serialized_start=301
  _CREATEASSIGNMENTV2INPUT._serialized_end=465
  _CREATEASSIGNMENTV2OUTPUT._serialized_start=467
  _CREATEASSIGNMENTV2OUTPUT._serialized_end=493
  _DELETEASSIGNMENTV2INPUT._serialized_start=495
  _DELETEASSIGNMENTV2INPUT._serialized_end=539
  _DELETEASSIGNMENTV2OUTPUT._serialized_start=541
  _DELETEASSIGNMENTV2OUTPUT._serialized_end=567
  _STARTASSIGNMENTV2INPUT._serialized_start=569
  _STARTASSIGNMENTV2INPUT._serialized_end=612
  _STARTASSIGNMENTV2OUTPUT._serialized_start=614
  _STARTASSIGNMENTV2OUTPUT._serialized_end=639
  _LISTASSIGNMENTSV2INPUT._serialized_start=641
  _LISTASSIGNMENTSV2INPUT._serialized_end=665
  _LISTASSIGNMENTSV2OUTPUT._serialized_start=667
  _LISTASSIGNMENTSV2OUTPUT._serialized_end=736
  _LISTASSIGNMENTITEMSV2INPUT._serialized_start=738
  _LISTASSIGNMENTITEMSV2INPUT._serialized_end=785
  _LISTASSIGNMENTITEMSV2OUTPUT._serialized_start=787
  _LISTASSIGNMENTITEMSV2OUTPUT._serialized_end=864
  _DESCRIBEASSIGNMENTITEMV2INPUT._serialized_start=866
  _DESCRIBEASSIGNMENTITEMV2INPUT._serialized_end=982
  _DESCRIBEASSIGNMENTITEMV2OUTPUT._serialized_start=984
  _DESCRIBEASSIGNMENTITEMV2OUTPUT._serialized_end=1063
  _UPDATEASSIGNMENTITEMV2INPUT._serialized_start=1066
  _UPDATEASSIGNMENTITEMV2INPUT._serialized_end=1320
  _UPDATEASSIGNMENTITEMV2INPUT_PATCH._serialized_start=1245
  _UPDATEASSIGNMENTITEMV2INPUT_PATCH._serialized_end=1320
  _UPDATEASSIGNMENTITEMV2OUTPUT._serialized_start=1322
  _UPDATEASSIGNMENTITEMV2OUTPUT._serialized_end=1352
  _RESETASSIGNMENTITEMV2INPUT._serialized_start=1354
  _RESETASSIGNMENTITEMV2INPUT._serialized_end=1418
  _RESETASSIGNMENTITEMV2OUTPUT._serialized_start=1420
  _RESETASSIGNMENTITEMV2OUTPUT._serialized_end=1449
  _ASSIGNMENTSERVICEV2._serialized_start=1452
  _ASSIGNMENTSERVICEV2._serialized_end=2977
# @@protoc_insertion_point(module_scope)
