# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/assignment_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import assignment_pb2 as eolymp_dot_course_dot_assignment__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/course/assignment_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/course/assignment.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\"\xbf\x03\n\x14ListAssignmentsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.course.ListAssignmentsInput.Filter\x12:\n\x04sort\x18\x32 \x01(\x0e\x32,.eolymp.course.ListAssignmentsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.course.Assignment.Extra\x1a\x99\x01\n\x06\x46ilter\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08group_id\x18\x0c \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"\x17\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\"P\n\x15ListAssignmentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.course.Assignment\"a\n\x17\x44\x65scribeAssignmentInput\x12\x15\n\rassignment_id\x18\x01 \x01(\t\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.course.Assignment.Extra\"I\n\x18\x44\x65scribeAssignmentOutput\x12-\n\nassignment\x18\x01 \x01(\x0b\x32\x19.eolymp.course.Assignment\"\x1b\n\x19IntrospectAssignmentInput\"K\n\x1aIntrospectAssignmentOutput\x12-\n\nassignment\x18\x01 \x01(\x0b\x32\x19.eolymp.course.Assignment\"F\n\x15\x43reateAssignmentInput\x12-\n\nassignment\x18\x01 \x01(\x0b\x32\x19.eolymp.course.Assignment\"/\n\x16\x43reateAssignmentOutput\x12\x15\n\rassignment_id\x18\x01 \x01(\t\"\xe9\x01\n\x15UpdateAssignmentInput\x12\x39\n\x05patch\x18\x01 \x03(\x0e\x32*.eolymp.course.UpdateAssignmentInput.Patch\x12\x15\n\rassignment_id\x18\x02 \x01(\t\x12-\n\nassignment\x18\x03 \x01(\x0b\x32\x19.eolymp.course.Assignment\"O\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0f\n\x0bSTART_AFTER\x10\x01\x12\x13\n\x0f\x43OMPLETE_BEFORE\x10\x02\x12\x0c\n\x08\x44URATION\x10\x03\x12\t\n\x05ITEMS\x10\x04\"\x18\n\x16UpdateAssignmentOutput\".\n\x15\x44\x65leteAssignmentInput\x12\x15\n\rassignment_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteAssignmentOutput\"(\n\x14StartAssignmentInput\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\t\"\x17\n\x15StartAssignmentOutput2\x9e\t\n\x11\x41ssignmentService\x12\x9f\x01\n\x10\x43reateAssignment\x12$.eolymp.course.CreateAssignmentInput\x1a%.eolymp.course.CreateAssignmentOutput\">\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\x1a\x0c/assignments\x12\xaf\x01\n\x10UpdateAssignment\x12$.eolymp.course.UpdateAssignmentInput\x1a%.eolymp.course.UpdateAssignmentOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/assignments/{assignment_id}\x12\xaf\x01\n\x10\x44\x65leteAssignment\x12$.eolymp.course.DeleteAssignmentInput\x1a%.eolymp.course.DeleteAssignmentOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x1c/assignments/{assignment_id}\x12\xb4\x01\n\x12\x44\x65scribeAssignment\x12&.eolymp.course.DescribeAssignmentInput\x1a\'.eolymp.course.DescribeAssignmentOutput\"M\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1e\x12\x1c/assignments/{assignment_id}\x12\xb0\x01\n\x14IntrospectAssignment\x12(.eolymp.course.IntrospectAssignmentInput\x1a).eolymp.course.IntrospectAssignmentOutput\"C\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x14\x12\x12/viewer/assignment\x12\x9b\x01\n\x0fListAssignments\x12#.eolymp.course.ListAssignmentsInput\x1a$.eolymp.course.ListAssignmentsOutput\"=\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0e\x12\x0c/assignments\x12{\n\x0fStartAssignment\x12#.eolymp.course.StartAssignmentInput\x1a$.eolymp.course.StartAssignmentOutput\"\x1d\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x08\"\x06/startB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.assignment_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _ASSIGNMENTSERVICE.methods_by_name['CreateAssignment']._options = None
  _ASSIGNMENTSERVICE.methods_by_name['CreateAssignment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\016\032\014/assignments'
  _ASSIGNMENTSERVICE.methods_by_name['UpdateAssignment']._options = None
  _ASSIGNMENTSERVICE.methods_by_name['UpdateAssignment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\032\034/assignments/{assignment_id}'
  _ASSIGNMENTSERVICE.methods_by_name['DeleteAssignment']._options = None
  _ASSIGNMENTSERVICE.methods_by_name['DeleteAssignment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036*\034/assignments/{assignment_id}'
  _ASSIGNMENTSERVICE.methods_by_name['DescribeAssignment']._options = None
  _ASSIGNMENTSERVICE.methods_by_name['DescribeAssignment']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\036\022\034/assignments/{assignment_id}'
  _ASSIGNMENTSERVICE.methods_by_name['IntrospectAssignment']._options = None
  _ASSIGNMENTSERVICE.methods_by_name['IntrospectAssignment']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\024\022\022/viewer/assignment'
  _ASSIGNMENTSERVICE.methods_by_name['ListAssignments']._options = None
  _ASSIGNMENTSERVICE.methods_by_name['ListAssignments']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\016\022\014/assignments'
  _ASSIGNMENTSERVICE.methods_by_name['StartAssignment']._options = None
  _ASSIGNMENTSERVICE.methods_by_name['StartAssignment']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\010\"\006/start'
  _LISTASSIGNMENTSINPUT._serialized_start=258
  _LISTASSIGNMENTSINPUT._serialized_end=705
  _LISTASSIGNMENTSINPUT_FILTER._serialized_start=527
  _LISTASSIGNMENTSINPUT_FILTER._serialized_end=680
  _LISTASSIGNMENTSINPUT_SORTABLE._serialized_start=682
  _LISTASSIGNMENTSINPUT_SORTABLE._serialized_end=705
  _LISTASSIGNMENTSOUTPUT._serialized_start=707
  _LISTASSIGNMENTSOUTPUT._serialized_end=787
  _DESCRIBEASSIGNMENTINPUT._serialized_start=789
  _DESCRIBEASSIGNMENTINPUT._serialized_end=886
  _DESCRIBEASSIGNMENTOUTPUT._serialized_start=888
  _DESCRIBEASSIGNMENTOUTPUT._serialized_end=961
  _INTROSPECTASSIGNMENTINPUT._serialized_start=963
  _INTROSPECTASSIGNMENTINPUT._serialized_end=990
  _INTROSPECTASSIGNMENTOUTPUT._serialized_start=992
  _INTROSPECTASSIGNMENTOUTPUT._serialized_end=1067
  _CREATEASSIGNMENTINPUT._serialized_start=1069
  _CREATEASSIGNMENTINPUT._serialized_end=1139
  _CREATEASSIGNMENTOUTPUT._serialized_start=1141
  _CREATEASSIGNMENTOUTPUT._serialized_end=1188
  _UPDATEASSIGNMENTINPUT._serialized_start=1191
  _UPDATEASSIGNMENTINPUT._serialized_end=1424
  _UPDATEASSIGNMENTINPUT_PATCH._serialized_start=1345
  _UPDATEASSIGNMENTINPUT_PATCH._serialized_end=1424
  _UPDATEASSIGNMENTOUTPUT._serialized_start=1426
  _UPDATEASSIGNMENTOUTPUT._serialized_end=1450
  _DELETEASSIGNMENTINPUT._serialized_start=1452
  _DELETEASSIGNMENTINPUT._serialized_end=1498
  _DELETEASSIGNMENTOUTPUT._serialized_start=1500
  _DELETEASSIGNMENTOUTPUT._serialized_end=1524
  _STARTASSIGNMENTINPUT._serialized_start=1526
  _STARTASSIGNMENTINPUT._serialized_end=1566
  _STARTASSIGNMENTOUTPUT._serialized_start=1568
  _STARTASSIGNMENTOUTPUT._serialized_end=1591
  _ASSIGNMENTSERVICE._serialized_start=1594
  _ASSIGNMENTSERVICE._serialized_end=2776
# @@protoc_insertion_point(module_scope)
