# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/module_item_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import module_item_pb2 as eolymp_dot_course_dot_module__item__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'eolymp/course/module_item_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1f\x65olymp/course/module_item.proto\x1a eolymp/wellknown/direction.proto\"@\n\x15\x43reateModuleItemInput\x12\'\n\x04item\x18\x01 \x01(\x0b\x32\x19.eolymp.course.ModuleItem\")\n\x16\x43reateModuleItemOutput\x12\x0f\n\x07item_id\x18\x01 \x01(\t\"\xf2\x01\n\x15UpdateModuleItemInput\x12\x39\n\x05patch\x18\x01 \x03(\x0e\x32*.eolymp.course.UpdateModuleItemInput.Patch\x12\x0f\n\x07item_id\x18\x02 \x01(\t\x12\'\n\x04item\x18\x03 \x01(\x0b\x32\x19.eolymp.course.ModuleItem\"d\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\r\n\tIMAGE_URL\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\t\n\x05\x44\x45PTH\x10\x05\x12\x0b\n\x07\x43ONTENT\x10\x06\x12\x0b\n\x07GRADING\x10\x07\"\x18\n\x16UpdateModuleItemOutput\"c\n\x13MoveModuleItemInput\x12\x0f\n\x07item_id\x18\x01 \x01(\t\x12\x15\n\rnew_module_id\x18\x02 \x01(\t\x12\x11\n\tnew_index\x18\x03 \x01(\r\x12\x11\n\tnew_depth\x18\x04 \x01(\r\"\x16\n\x14MoveModuleItemOutput\"(\n\x15\x44\x65leteModuleItemInput\x12\x0f\n\x07item_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteModuleItemOutput\"[\n\x17\x44\x65scribeModuleItemInput\x12\x0f\n\x07item_id\x18\x01 \x01(\t\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.course.ModuleItem.Extra\"C\n\x18\x44\x65scribeModuleItemOutput\x12\'\n\x04item\x18\x01 \x01(\x0b\x32\x19.eolymp.course.ModuleItem\"\xb2\x02\n\x14ListModuleItemsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.course.ListModuleItemsInput.Filter\x12\x36\n\x04sort\x18\x32 \x01(\x0e\x32(.eolymp.course.ListModuleItemsInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.course.ModuleItem.Extra\x1a\x17\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\"\x11\n\x04Sort\x12\t\n\x05INDEX\x10\x00\"P\n\x15ListModuleItemsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.course.ModuleItem2\xe3\x07\n\x11ModuleItemService\x12\x99\x01\n\x10\x43reateModuleItem\x12$.eolymp.course.CreateModuleItemInput\x1a%.eolymp.course.CreateModuleItemOutput\"8\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x08\"\x06/items\x12\xa3\x01\n\x10UpdateModuleItem\x12$.eolymp.course.UpdateModuleItemInput\x1a%.eolymp.course.UpdateModuleItemOutput\"B\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x12\x1a\x10/items/{item_id}\x12\xa2\x01\n\x0eMoveModuleItem\x12\".eolymp.course.MoveModuleItemInput\x1a#.eolymp.course.MoveModuleItemOutput\"G\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x17\"\x15/items/{item_id}/move\x12\xa3\x01\n\x10\x44\x65leteModuleItem\x12$.eolymp.course.DeleteModuleItemInput\x1a%.eolymp.course.DeleteModuleItemOutput\"B\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x12*\x10/items/{item_id}\x12\xa8\x01\n\x12\x44\x65scribeModuleItem\x12&.eolymp.course.DescribeModuleItemInput\x1a\'.eolymp.course.DescribeModuleItemOutput\"A\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x12\x12\x10/items/{item_id}\x12\x95\x01\n\x0fListModuleItems\x12#.eolymp.course.ListModuleItemsInput\x1a$.eolymp.course.ListModuleItemsOutput\"7\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x08\x12\x06/itemsB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.module_item_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _MODULEITEMSERVICE.methods_by_name['CreateModuleItem']._options = None
  _MODULEITEMSERVICE.methods_by_name['CreateModuleItem']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\010\"\006/items'
  _MODULEITEMSERVICE.methods_by_name['UpdateModuleItem']._options = None
  _MODULEITEMSERVICE.methods_by_name['UpdateModuleItem']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\022\032\020/items/{item_id}'
  _MODULEITEMSERVICE.methods_by_name['MoveModuleItem']._options = None
  _MODULEITEMSERVICE.methods_by_name['MoveModuleItem']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\027\"\025/items/{item_id}/move'
  _MODULEITEMSERVICE.methods_by_name['DeleteModuleItem']._options = None
  _MODULEITEMSERVICE.methods_by_name['DeleteModuleItem']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\022*\020/items/{item_id}'
  _MODULEITEMSERVICE.methods_by_name['DescribeModuleItem']._options = None
  _MODULEITEMSERVICE.methods_by_name['DescribeModuleItem']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\022\022\020/items/{item_id}'
  _MODULEITEMSERVICE.methods_by_name['ListModuleItems']._options = None
  _MODULEITEMSERVICE.methods_by_name['ListModuleItems']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\010\022\006/items'
  _CREATEMODULEITEMINPUT._serialized_start=224
  _CREATEMODULEITEMINPUT._serialized_end=288
  _CREATEMODULEITEMOUTPUT._serialized_start=290
  _CREATEMODULEITEMOUTPUT._serialized_end=331
  _UPDATEMODULEITEMINPUT._serialized_start=334
  _UPDATEMODULEITEMINPUT._serialized_end=576
  _UPDATEMODULEITEMINPUT_PATCH._serialized_start=476
  _UPDATEMODULEITEMINPUT_PATCH._serialized_end=576
  _UPDATEMODULEITEMOUTPUT._serialized_start=578
  _UPDATEMODULEITEMOUTPUT._serialized_end=602
  _MOVEMODULEITEMINPUT._serialized_start=604
  _MOVEMODULEITEMINPUT._serialized_end=703
  _MOVEMODULEITEMOUTPUT._serialized_start=705
  _MOVEMODULEITEMOUTPUT._serialized_end=727
  _DELETEMODULEITEMINPUT._serialized_start=729
  _DELETEMODULEITEMINPUT._serialized_end=769
  _DELETEMODULEITEMOUTPUT._serialized_start=771
  _DELETEMODULEITEMOUTPUT._serialized_end=795
  _DESCRIBEMODULEITEMINPUT._serialized_start=797
  _DESCRIBEMODULEITEMINPUT._serialized_end=888
  _DESCRIBEMODULEITEMOUTPUT._serialized_start=890
  _DESCRIBEMODULEITEMOUTPUT._serialized_end=957
  _LISTMODULEITEMSINPUT._serialized_start=960
  _LISTMODULEITEMSINPUT._serialized_end=1266
  _LISTMODULEITEMSINPUT_FILTER._serialized_start=1224
  _LISTMODULEITEMSINPUT_FILTER._serialized_end=1247
  _LISTMODULEITEMSINPUT_SORT._serialized_start=1249
  _LISTMODULEITEMSINPUT_SORT._serialized_end=1266
  _LISTMODULEITEMSOUTPUT._serialized_start=1268
  _LISTMODULEITEMSOUTPUT._serialized_end=1348
  _MODULEITEMSERVICE._serialized_start=1351
  _MODULEITEMSERVICE._serialized_end=2346
# @@protoc_insertion_point(module_scope)
