# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/configuration_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(eolymp/atlas/configuration_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\";\n\x15\x43onfigurePolygonInput\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\x18\n\x16\x43onfigurePolygonOutput\"\x16\n\x14\x44\x65scribePolygonInput\"?\n\x15\x44\x65scribePolygonOutput\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x14\n\x0cpassword_set\x18\x02 \x01(\x08\x32\xda\x02\n\x14\x43onfigurationService\x12\xa1\x01\n\x10\x43onfigurePolygon\x12#.eolymp.atlas.ConfigurePolygonInput\x1a$.eolymp.atlas.ConfigurePolygonOutput\"B\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x11\x1a\x0f/config/polygon\x12\x9d\x01\n\x0f\x44\x65scribePolygon\x12\".eolymp.atlas.DescribePolygonInput\x1a#.eolymp.atlas.DescribePolygonOutput\"A\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x11\x12\x0f/config/polygonB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.configuration_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _CONFIGURATIONSERVICE.methods_by_name['ConfigurePolygon']._options = None
  _CONFIGURATIONSERVICE.methods_by_name['ConfigurePolygon']._serialized_options = b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\021\032\017/config/polygon'
  _CONFIGURATIONSERVICE.methods_by_name['DescribePolygon']._options = None
  _CONFIGURATIONSERVICE.methods_by_name['DescribePolygon']._serialized_options = b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\021\022\017/config/polygon'
  _CONFIGUREPOLYGONINPUT._serialized_start=157
  _CONFIGUREPOLYGONINPUT._serialized_end=216
  _CONFIGUREPOLYGONOUTPUT._serialized_start=218
  _CONFIGUREPOLYGONOUTPUT._serialized_end=242
  _DESCRIBEPOLYGONINPUT._serialized_start=244
  _DESCRIBEPOLYGONINPUT._serialized_end=266
  _DESCRIBEPOLYGONOUTPUT._serialized_start=268
  _DESCRIBEPOLYGONOUTPUT._serialized_end=331
  _CONFIGURATIONSERVICE._serialized_start=334
  _CONFIGURATIONSERVICE._serialized_end=680
# @@protoc_insertion_point(module_scope)
