# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/linked_account_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.community import linked_account_pb2 as eolymp_dot_community_dot_linked__account__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-eolymp/community/linked_account_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a%eolymp/community/linked_account.proto\x1a!eolymp/wellknown/expression.proto\"-\n\x1a\x44\x65scribeLinkedAccountInput\x12\x0f\n\x07link_id\x18\x01 \x01(\t\"L\n\x1b\x44\x65scribeLinkedAccountOutput\x12-\n\x04link\x18\x01 \x01(\x0b\x32\x1f.eolymp.community.LinkedAccount\"\xe0\x01\n\x17ListLinkedAccountsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x41\n\x07\x66ilters\x18( \x01(\x0b\x32\x30.eolymp.community.ListLinkedAccountsInput.Filter\x1a\x64\n\x06\x46ilter\x12*\n\x02id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04type\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"Y\n\x18ListLinkedAccountsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.eolymp.community.LinkedAccount\"+\n\x18\x44\x65leteLinkedAccountInput\x12\x0f\n\x07link_id\x18\x01 \x01(\t\"\x1b\n\x19\x44\x65leteLinkedAccountOutput2\xfb\x03\n\x14LinkedAccountService\x12\xa7\x01\n\x15\x44\x65scribeLinkedAccount\x12,.eolymp.community.DescribeLinkedAccountInput\x1a-.eolymp.community.DescribeLinkedAccountOutput\"1\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1c\x12\x1a/linked-accounts/{link_id}\x12\x94\x01\n\x12ListLinkedAccounts\x12).eolymp.community.ListLinkedAccountsInput\x1a*.eolymp.community.ListLinkedAccountsOutput\"\'\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x12\x12\x10/linked-accounts\x12\xa1\x01\n\x13\x44\x65leteLinkedAccount\x12*.eolymp.community.DeleteLinkedAccountInput\x1a+.eolymp.community.DeleteLinkedAccountOutput\"1\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1c*\x1a/linked-accounts/{link_id}B5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.linked_account_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _LINKEDACCOUNTSERVICE.methods_by_name['DescribeLinkedAccount']._options = None
  _LINKEDACCOUNTSERVICE.methods_by_name['DescribeLinkedAccount']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\034\022\032/linked-accounts/{link_id}'
  _LINKEDACCOUNTSERVICE.methods_by_name['ListLinkedAccounts']._options = None
  _LINKEDACCOUNTSERVICE.methods_by_name['ListLinkedAccounts']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\022\022\020/linked-accounts'
  _LINKEDACCOUNTSERVICE.methods_by_name['DeleteLinkedAccount']._options = None
  _LINKEDACCOUNTSERVICE.methods_by_name['DeleteLinkedAccount']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\034*\032/linked-accounts/{link_id}'
  _DESCRIBELINKEDACCOUNTINPUT._serialized_start=208
  _DESCRIBELINKEDACCOUNTINPUT._serialized_end=253
  _DESCRIBELINKEDACCOUNTOUTPUT._serialized_start=255
  _DESCRIBELINKEDACCOUNTOUTPUT._serialized_end=331
  _LISTLINKEDACCOUNTSINPUT._serialized_start=334
  _LISTLINKEDACCOUNTSINPUT._serialized_end=558
  _LISTLINKEDACCOUNTSINPUT_FILTER._serialized_start=458
  _LISTLINKEDACCOUNTSINPUT_FILTER._serialized_end=558
  _LISTLINKEDACCOUNTSOUTPUT._serialized_start=560
  _LISTLINKEDACCOUNTSOUTPUT._serialized_end=649
  _DELETELINKEDACCOUNTINPUT._serialized_start=651
  _DELETELINKEDACCOUNTINPUT._serialized_end=694
  _DELETELINKEDACCOUNTOUTPUT._serialized_start=696
  _DELETELINKEDACCOUNTOUTPUT._serialized_end=723
  _LINKEDACCOUNTSERVICE._serialized_start=726
  _LINKEDACCOUNTSERVICE._serialized_end=1233
# @@protoc_insertion_point(module_scope)
