# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/module_item.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65olymp/course/module_item.proto\x12\reolymp.course\x1a\x18\x65olymp/ecm/content.proto\"\xe6\x03\n\nModuleItem\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05\x64raft\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\timage_url\x18\x05 \x01(\t\x12\r\n\x05index\x18\x0b \x01(\r\x12\r\n\x05\x64\x65pth\x18\x0c \x01(\r\x12\x32\n\x07grading\x18\x1e \x01(\x0b\x32!.eolymp.course.ModuleItem.Grading\x12\x36\n\x08\x64ocument\x18\x64 \x01(\x0b\x32\".eolymp.course.ModuleItem.DocumentH\x00\x12.\n\x04task\x18\x65 \x01(\x0b\x32\x1e.eolymp.course.ModuleItem.TaskH\x00\x1a\x30\n\x08\x44ocument\x12$\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x13.eolymp.ecm.Content\x1a\x1a\n\x04Task\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x1a,\n\x07Grading\x12\x11\n\tmax_score\x18\x01 \x01(\r\x12\x0e\n\x06weight\x18\x02 \x01(\x02\"N\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x12\x0b\n\x07\x43ONTENT\x10\x01\x12\x11\n\rCONTENT_VALUE\x10\x02\x12\x12\n\x0e\x43ONTENT_RENDER\x10\x03\x42\t\n\x07\x63ontentB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.module_item_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _MODULEITEM._serialized_start=77
  _MODULEITEM._serialized_end=563
  _MODULEITEM_DOCUMENT._serialized_start=350
  _MODULEITEM_DOCUMENT._serialized_end=398
  _MODULEITEM_TASK._serialized_start=400
  _MODULEITEM_TASK._serialized_end=426
  _MODULEITEM_GRADING._serialized_start=428
  _MODULEITEM_GRADING._serialized_end=472
  _MODULEITEM_EXTRA._serialized_start=474
  _MODULEITEM_EXTRA._serialized_end=552
# @@protoc_insertion_point(module_scope)
